<p align="center">
# By Traders, For Traders.
</p>

<p align="center">
    <img src ="https://img.shields.io/badge/platform-windows|linux|macos-yellow.svg"/>
    <img src ="https://img.shields.io/badge/python-3.7-blue.svg" />
</p>

egopy是一套基于Python的开源量化交易系统开发框架。

<p align="center">
</p>

在使用egopy进行二次开发（策略、模块等）的过程中有任何疑问，请查看[**egopy项目文档**]

## 功能特点

1. 全功能量化交易平台（egopy.trader），整合了多种交易接口，并针对具体策略算法和功能开发提供了简洁易用的API，用于快速构建交易员所需的量化交易应用。

2. 覆盖国内外所有交易品种的交易接口（egopy.gateway）：

    * 国内市场

    * 海外市场

    * 特殊应用

3. 开箱即用的各类量化策略交易应用（egopy.app）：

## 环境准备

* 推荐使用egopy团队为量化交易专门打造的Python发行版，内置了最新版的egopy框架
* 支持的系统版本：Windows 10以上/Windows Server 2016以上/Ubuntu 20.04 LTS以上
* 支持的Python版本：Python 3.7 64位（**注意必须是Python 3.7 64位版本**）

## 安装步骤

## 使用指南

1. 在[SimNow](http://www.simnow.com.cn/)注册CTP仿真账号，并在[该页面](http://www.simnow.com.cn/product.action)获取经纪商代码以及交易行情服务器地址。

## 版权说明

MIT
